
export Parafin

struct Parafin <: Fluid
    name::Symbol
    ρ::Float64
    cₚ::Float64
    μ::Float64
    k::Float64

    base_fluid::Fluid

    k_params::Array{Float64,2}

    function Parafin()
        MM=170.33484
        # Acording to Lemmon2004 for dodecane
        Tc=658.1
        Pc=1.817E6
        ω=0.574182221240689

        # Acording to Zheng et al. (2021)
        k_params = [
            3.230419E-1    -2.479848E-3
            -1.001512E-3   1.789301E-5
            1.57871E-6     -3.460690E-8
            -9.937761E-10  2.190388E-11
        ]

        new(
            :Parafin,
            803.2269519969861,
            373.30/MM*1000.0,
            0.00134,
            9999.0,
            nDodecane(),
            k_params
        )

    end
end

function rho(P,T,fluid::Parafin)
    A=[6.9692,3.35E-5,-5E-10]
    B=[-3.46E-3,-1.64E-8,2E-13]
    Ppsia=P*pascal_to_psi
    TFar=(T-273.15)*(9/5)+32
    Pv=[1 Ppsia Ppsia^2]
    return (dot(A,Pv)+dot(B,Pv)*TFar)*ppg_to_SI
end


therm_cond(P,T,fluid::Parafin) = therm_cond(P*1.0E-6,T,fluid,DrillMudsThermalProps.kfit)


Cp(P,T,fluid::Parafin,model::CpPStd) = Cp(P,T,fluid.base_fluid,model)

Cp(P,T,fluid::Parafin) = Cp(P,T,fluid,cpP)
